@@ -9,7 +9,7 @@ import json
 from ladybug.color import Color
 from honeybee_vtk.model import Model
 from honeybee_vtk.vtkjs.schema import SensorGridOptions, DisplayMode
-from honeybee_vtk.types import ImageTypes
+from honeybee_vtk.types import ImageTypes, RadialSensor
 from honeybee_vtk.text_actor import TextActor
 from honeybee_vtk.config import TimeStepDataConfig
 from honeybee_vtk.time_step_images import export_time_step_images
@@ -53,7 +53,8 @@ def export():
 )
 @click.option(
     '--grid-options', '-go',
-    type=click.Choice(['ignore', 'points', 'meshes'], case_sensitive=False),
+    type=click.Choice(['ignore', 'points', 'meshes', 'radial-grid'],
+                      case_sensitive=False),
     default='ignore', help='Export sensor grids as either points or meshes.',
     show_default=True,
 )
@@ -64,6 +65,16 @@ def export():
     default='shaded', help='Set display mode for the Sensorgrids.',
     show_default=True
 )
+@click.option(
+    '--triangle-angle', '-ta', type=int, default=45, help='Set the internal angle of the'
+    'triangles in the grid in case radial-grid is selected from grid options',
+    show_default=True
+)
+@click.option(
+    '--triangle-radius', '-tr', type=float, default=None, help='Set the radial height of'
+    'the triangles in the grid in case radial-grid is selected from grid options',
+    show_default=True
+)
 @click.option(
     '--view', '-vf', help='File Path to the Radiance view file. Multiple view files are'
     ' accepted.', type=click.Path(exists=True), default=None,
@@ -82,7 +93,7 @@ def export():
 def model_images(
         hbjson_file, folder, image_type, image_width, image_height,
         background_color, model_display_mode, grid_options, grid_display_mode,
-        view, config, validate_data,):
+        triangle_angle, triangle_radius, view, config, validate_data,):
     """Export images of the Honeybee Model created from the HBJSON file.
 
     \b
@@ -107,11 +118,13 @@ def model_images(
         image_type == ImageTypes.pnm
 
     if grid_options.lower() == 'ignore':
-        grid_option = SensorGridOptions.Ignore
+        grid_options = SensorGridOptions.Ignore
     elif grid_options.lower() == 'points':
-        grid_option = SensorGridOptions.Sensors
+        grid_options = SensorGridOptions.Sensors
     elif grid_options.lower() == 'meshes':
-        grid_option = SensorGridOptions.Mesh
+        grid_options = SensorGridOptions.Mesh
+    elif grid_options.lower() == 'radial-grid':
+        grid_options = SensorGridOptions.RadialGrid
 
     if model_display_mode.lower() == 'shaded':
         model_display_mode = DisplayMode.Shaded
@@ -136,7 +149,9 @@ def model_images(
         grid_display_mode = DisplayMode.Points
 
     try:
-        model = Model.from_hbjson(hbjson=hbjson_file, load_grids=grid_option)
+        model = Model.from_hbjson(hbjson=hbjson_file, load_grids=grid_options,
+                                  radial_sensor=RadialSensor(triangle_angle,
+                                                             triangle_radius))
 
         output = model.to_images(
             folder=folder.as_posix(),
@@ -267,12 +282,13 @@ def grid_images(
     elif image_type.lower() == 'pnm':
         image_type == ImageTypes.pnm
 
-    if grid_options.lower() == 'ignore':
-        grid_option = SensorGridOptions.Ignore
-    elif grid_options.lower() == 'points':
-        grid_option = SensorGridOptions.Sensors
-    elif grid_options.lower() == 'meshes':
-        grid_option = SensorGridOptions.Mesh
+    # Set Sensor grids
+    if grid_options == 'ignore':
+        grid_options = SensorGridOptions.Ignore
+    elif grid_options == 'points':
+        grid_options = SensorGridOptions.Sensors
+    elif grid_options == 'meshes':
+        grid_options = SensorGridOptions.Mesh
 
     if grid_display_mode.lower() == 'shaded':
         grid_display_mode = DisplayMode.Shaded
@@ -286,7 +302,7 @@ def grid_images(
         grid_display_mode = DisplayMode.Points
 
     try:
-        model = Model.from_hbjson(hbjson=hbjson_file, load_grids=grid_option)
+        model = Model.from_hbjson(hbjson=hbjson_file, load_grids=grid_options)
 
         text_actor = TextActor(text=text_content, height=text_height, color=text_color,
                                position=text_position, bold=text_bold)\
